@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2012 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,8 @@
 
 // common implementation headers
 #include "bzfio.h"
+#include "Protocol.h"
+#include "TextUtils.h"
 
 bool		    cURLManager::inited      = false;
 bool		    cURLManager::justCalled;
@@ -181,7 +183,7 @@ void cURLManager::setHTTPPostMode()
     logDebugMessage(1,"CURLOPT_HTTPPOST error %d : %s\n", result, errorBuffer);
 }
 
-void cURLManager::setURL(const std::string url)
+void cURLManager::setURL(const std::string &url)
 {
   CURLcode result;
 
@@ -199,6 +201,13 @@ void cURLManager::setURL(const std::string url)
   }
 }
 
+void cURLManager::setURLwithNonce(const std::string &url)
+{
+  // only the default list server is known to support the nonce parameter
+  const std::string nonce = (strcasecmp(url.c_str(), DefaultListServerURL) == 0) ? TextUtils::format("?nocache=%lu", time(0)) : "";
+  setURL(url + nonce);
+}
+
 void cURLManager::setProgressFunction(curl_progress_callback func, void* data)
 {
   CURLcode result;
@@ -396,7 +405,7 @@ void cURLManager::setTimeCondition(timeCondition condition, time_t &t)
   }
 }
 
-void cURLManager::setInterface(const std::string _interfaceIP)
+void cURLManager::setInterface(const std::string &_interfaceIP)
 {
   interfaceIP = _interfaceIP;
 
@@ -409,7 +418,7 @@ void cURLManager::setInterface(const std::string _interfaceIP)
     logDebugMessage(1,"CURLOPT_SET_INTERFACE error %d : %s\n", result, errorBuffer);
 }
 
-void cURLManager::setUserAgent(const std::string _userAgent)
+void cURLManager::setUserAgent(const std::string &_userAgent)
 {
   userAgent = _userAgent;
 
